import React from 'react';
/**
 * The script tag that loads the Usercentrics Browser UI & API.
 *
 * @example <caption>Default production mode</caption>
 * () => <UsercentricsScript settingsId="1234" />
 *
 * @example <caption>Preview mode for development</caption>
 * () => <UsercentricsScript settingsId="1234" version="preview" />
 *
 * @example <caption>Use SDK v3 instead of previous v2</caption>
 * () => <UsercentricsScript cmpVersion="3" settingsId="1234" />
 *
 * @example <caption>Fixed UI version instead of latest</caption>
 * () => <UsercentricsScript settingsId="1234" uiVersion="3.24.0" />
 *
 * @example <caption>Fixed language code</caption>
 * () => <UsercentricsScript settingsId="1234" language="fi" />
 *
 */
export const UsercentricsScript = ({ id = 'usercentrics-cmp', language, settingsId, version, ...rest }) => {
    return (React.createElement("script", { ...rest, async: 'async' in rest ? rest.async : true, "data-language": language, "data-settings-id": settingsId, "data-version": version, id: id, src: "https://web.cmp.usercentrics.eu/ui/loader.js" }));
};
